import {useEffect, useMemo, useState} from "react";
import dayjs from "dayjs";
import {DATE_TIME_FORMAT} from "../utils/timeFormatUtil";
import {getTaskByPid} from "../utils";
import {Cascader} from "antd-mobile";

export function useChildList() {
    const [task, setTask] = useState({
        name: "想做的事情",
        description: "想做的事情描述",
        expectedStartTime: dayjs().format(DATE_TIME_FORMAT),
        expectedEndTime: "",
        state: "",
        priority: "",
    });
    // Map key为pid和他的子项
    const [childList, setChildList] = useState({});

    useEffect(() => {
        fetchOptionsForValue('0', 0)
    }, [])

    // list嵌套选中项的list
    const options = useMemo(() => {
        function generate(v) {
            const options = childList[v]
            if (options === null) {
                return undefined
            }
            if (options === undefined) {
                return Cascader.optionSkeleton
            }
            return options.map(option => ({
                ...option,
                children: generate(option.value),
            }))
        }

        return generate('0') ?? []
    }, [childList])

    async function fetchOptionsForValue(v, level) {
        if (v in childList) return
        const data = await getTaskByPid(v)
        const options =
            data.content.length === 0
                ? null
                : data.content.map(task => ({
                    value: task.id,
                    label: task.name,
                    ...task,
                }))

        setChildList(prev => ({
            ...prev,
            [v]: options,
        }))

    }

    function changeTaskId(taskId) {
        if (!(taskId && taskId.length > 0)) {
            return;
        }
        let currentTaskId = taskId[taskId.length - 1];
        fetchOptionsForValue(currentTaskId);
        if (taskId.length > 1) {
            setTask(childList[taskId[taskId.length - 2]].find(task => task.id === currentTaskId))
        } else {
            setTask(childList['0'].find(task => task.id === currentTaskId))
        }
    }

    function removeTaskId(taskId) {
        childList.delete(taskId);
        setChildList(...childList)
    }

    return {
        changeTaskId,
        removeTaskId,
        options,
        task
    };
}